@@ -8,6 +8,7 @@ designed to be as straight forward and Pythonic as possible.
 Creating messages:
 
     Message(type, **parameters) -- create a new message
+    MetaMessage(type, **parameters) -- create a new meta message
 
 Ports:
 
@@ -20,6 +21,17 @@ Ports:
     get_output_names() -- return a list of names of available output ports
     get_ioport_names() -- return a list of names of available I/O ports
 
+MIDI files:
+
+    MidiFile(filename, **kwargs) -- open a MIDI file
+    MidiTrack()  -- a MIDI track
+
+SYX files:
+
+    read_syx_file(filename)  -- read a SYX file
+    write_syx_file(filename, messages,
+                   plaintext=False)  -- write a SYX file
+
 Parsing MIDI streams:
 
     parse(bytes) -- parse a single message bytes
@@ -75,17 +87,19 @@ Getting started:
 """
 from __future__ import absolute_import
 import os
-from .backends import Backend
+from .backends.backend import Backend
 from . import ports, sockets
 from .messages import Message
 from .messages import parse_string, parse_string_stream, format_as_string
 from .parser import Parser, parse, parse_all
+from .midifiles import MidiFile, MidiTrack, MetaMessage
+from .syx import read_syx_file, write_syx_file
 
 __author__ = 'Ole Martin Bjorndalen'
 __email__ = 'ombdalen@gmail.com'
 __url__ = 'http://mido.readthedocs.org/'
 __license__ = 'MIT'
-__version__ = '1.1.6'
+__version__ = '1.1.7'
 
 # Prevent splat import.
 __all__ = []
