@@ -32,6 +32,7 @@ from .ports import BaseOutput
 from .types import encode_variable_int
 from .messages import build_message, Message, get_spec
 from .midifiles_meta import MetaMessage, _build_meta_message, meta_charset
+from .midifiles_meta import MetaSpec, add_meta_spec
 from . import midifiles_meta
 
 # The default tempo is 120 BPM.
@@ -359,45 +360,57 @@ class MidiFile:
 
         return max(track_lengths)
 
-    def play(self, meta_messages=False):
-        """Play back all tracks.
-
-        The generator will sleep between each message, so that
-        messages are yielded with correct timing. The time attribute
-        is set to the number of seconds slept since the previous
-        message.
-
-        You will receive copies of the original messages, so you can
-        safely modify them without ruining the tracks.
-        """
-
+    def __iter__(self):
         # The tracks of type 2 files are not in sync, so they can
         # not be played back like this.
         if self.type == 2:
             raise TypeError('type 2 file can not be played back like this')
 
         seconds_per_tick = self._compute_tick_time(DEFAULT_TEMPO)
-
         messages = self._merge_tracks(self.tracks)
 
-        # Play back messages.
         now = 0
         for message in messages:
-            delta = message.time - now
-            if delta:
-                sleep_time = delta * seconds_per_tick
-                time.sleep(sleep_time)
+            delta = (message.time - now) * seconds_per_tick
+            if delta >= 0:
+                message.time = delta
             else:
-                sleep_time = 0.0
+                message.time = 0.0
 
-            if meta_messages or isinstance(message, Message):
-                message.time = sleep_time
-                yield message
+            yield message
 
             now += delta
             if message.type == 'set_tempo':
                 seconds_per_tick = self._compute_tick_time(message.tempo)
 
+    def play(self, meta_messages=False):
+        """Play back all tracks.
+
+        The generator will sleep between each message by
+        default. Messages are yielded with correct timing. The time
+        attribute is set to the number of seconds slept since the
+        previous message.
+
+        If you pass sleep=False, the generator will not sleep between
+        messages. The messages will still be tagged with the number of
+        seconds it would have slept.
+
+        By default you will only get normal MIDI messages. Pass
+        meta_messages=True if you also want meta messages.
+
+        You will receive copies of the original messages, so you can
+        safely modify them without ruining the tracks.
+        """
+        sleep = time.sleep
+
+        for message in self:
+            sleep(message.time)
+
+            if isinstance(message, MetaMessage) and not meta_messages:
+                continue
+            else:
+                yield message
+
     def _has_end_of_track(self, track):
         """Return True if there is an end_of_track at the end of the track."""
         last_i = len(track) - 1
